decisionMatrix <- function(x, y,
                           wx = rep(1, nrow(x)),
                           wy = rep(1, nrow(y)),
                           size = rep(1, ncol(x)),
                           names = colnames(x),
                           xlab = "How attractive is the segment to us?",
                           ylab = "How attractive are we to the segment?",
                           ...) {
    stopifnot(is.matrix(x), is.numeric(x) | is.integer(x), all(x >= 0))
    stopifnot(is.matrix(y), is.numeric(y) | is.integer(y), all(y >= 0))
    stopifnot(identical(dim(x), dim(y)))
    stopifnot(is.vector(wx), is.numeric(wx) | is.integer(wx),
              all(wx >= 0), length(wx) == nrow(x), sum(wx) > 0)
    stopifnot(is.vector(wy), is.numeric(wy) | is.integer(wy),
              all(wy >= 0), length(wy) == nrow(y), sum(wy) > 0)
    stopifnot(is.vector(size), is.numeric(size) | is.integer(size),
              all(size >= 0), length(size) == ncol(x))
    stopifnot(is.vector(xlab), is.character(xlab), length(xlab) == 1)
    stopifnot(is.vector(ylab), is.character(ylab), length(ylab) == 1)
    
    if (is.null(names)) {
        names <- as.character(1:ncol(x))
    } 
    stopifnot(is.vector(names), is.character(names), length(names) == ncol(x))

    size <- size * 3
    
    wx <- wx / sum(wx)
    wy <- wy / sum(wy)

    px <- wx %*% x
    py <- wy %*% y

    limits <- c(0, ceiling(max(px, py)))
    
    plot(px, py, pch = 1, cex = size, xlim = limits, ylim = limits,
         xlab = xlab, ylab = ylab, ...)
    grid()
    mtext("not at all", side = 1, line = 2, adj = 0)
    mtext("very", side = 1, line = 2, adj = 1)
    mtext("not at all", side = 2, line = 2, adj = 0)
    mtext("very", side = 2, line = 2, adj = 1)

    text(px, py, names)
}


