vsbd <- function(x, centers, delta, phi = 1, initial.variables = 4, max.variables = ncol(x),
                 nstart1 = 50, nstart2 = 100, ...) {
    x <- as.matrix(x)
    stopifnot(isTRUE(all.equal(as.integer(x), as.vector(x))),
              length(setdiff(unique(as.integer(x)), c(0, 1))) == 0)
    stopifnot(is.numeric(delta), length(delta) == 1, delta >= 0, delta <= 1)
    stopifnot(is.numeric(phi), length(phi) == 1, phi > 0, phi <= 1)
    stopifnot(is.numeric(initial.variables), length(initial.variables) == 1)
    initial.variables <- min(as.integer(initial.variables), ncol(x))
    stopifnot(max.variables >= initial.variables, max.variables <= ncol(x))

    n.sub <- round(phi * nrow(x))
    if (n.sub < nrow(x)) {
        x <- x[sample(nrow(x), n.sub),, drop = FALSE]
    }

    perm <- gtools::combinations(ncol(x), initial.variables)
    initial.results <- lapply(seq_len(nrow(perm)), function(i) {
        kmeans(x[, perm[i, ], drop = FALSE], centers = centers, nstart = nstart1, ...)
    })

    WSS <- vapply(initial.results, function(x) sum(x$withinss), numeric(1))
    selected.variables <- perm[which.min(WSS), ]
    best.WSS <- min(WSS)
    
    while (length(selected.variables) < max.variables) {
        cols <- seq_len(ncol(x))[-selected.variables]
        intermediate.results <- lapply(cols, function(j) {
            kmeans(x[, c(selected.variables, j)], centers = centers, nstart = nstart2, ...)
        })
        WSS <- vapply(intermediate.results, function(x) sum(x$withinss), numeric(1))
        if (min(WSS) > best.WSS + delta * nrow(x) / 4) {
            break
        }
        selected.variables <- c(selected.variables, cols[which.min(WSS)])
        best.WSS <- min(WSS)
    }
    selected.variables
}
