######################################################################
## STEP 10
## Evaluation and monitoring
######################################################################

suppressWarnings(RNGversion("3.5"))

######################################################################
### 10.5 Example: Winter vacation activities
######################################################################

data("winterActiv2", package = "MSA")
p91 <- colMeans(wi91act)
round(100 * p91)
p97 <- colMeans(wi97act)
round(100 * p97)

dotchart(100 * sort(p97 - p91), xlab = paste("difference in",
  "percentages undertaking activity in '91 and '97"))
abline(v = 0, lty = 2)

library("flexclust")
set.seed(1234)
wi91act.k6 <- stepcclust(wi91act, k = 6, nrep = 20)

barchart(wi91act.k6, shade = TRUE, strip.prefix = "Segment ")

size91 <- table(clusters(wi91act.k6))
size97 <- table(clusters(wi91act.k6, newdata = wi97act))
round(prop.table(rbind(size91, size97), 1) * 100)

chisq.test(rbind(size91, size97))

mosaicplot(rbind("1991" = size91, "1997" = size97),
           ylab = "Segment", shade = TRUE, main = "")

wi97act.k6 <- cclust(wi97act, k = parameters(wi91act.k6))
barchart(wi97act.k6, shade = TRUE, strip.prefix = "Segment ")

print(barchart(wi91act.k6, shade = TRUE, strip.prefix = "Segment "),
      split = c(1, 1, 2, 1), more = TRUE)
print(barchart(wi97act.k6, shade = TRUE, strip.prefix = "Segment "),
      split = c(2, 1, 2, 1), more = FALSE)
