######################################################################
## STEP 4
## Exploring data
######################################################################

######################################################################
## 4.1 A first glimpse at the data
######################################################################

vaccsv <- system.file("csv/vacation.csv", package = "MSA")

## To copy the file to the current directory and read in this file
## uncomment the lines below.
## file.copy(vaccsv, ".")
## vac <- read.csv("vacation.csv", check.names = FALSE,
##   stringsAsFactors = TRUE)

vac <- read.csv(vaccsv, check.names = FALSE, stringsAsFactors = TRUE)
colnames(vac)
dim(vac)

summary(vac[, c(1, 2, 4, 5)])

######################################################################
## 4.2 Data cleaning
######################################################################

inc2 <- vac$Income2
levels(inc2)

lev <- levels(inc2)
lev

lev[c(1, 3, 4, 5, 2)]
inc2 <- factor(inc2, levels = lev[c(1, 3, 4, 5, 2)], ordered = TRUE)

table(orig = vac$Income2, new = inc2) 

vac$Income2 <- inc2 

######################################################################
## 4.3 Descriptive analysis
######################################################################

## Histogram
library("lattice")
histogram(~ Age, data = vac)
histogram(~ Age, data = vac, breaks = 50, type = "density")

## Boxplot
summary(vac$Age)
boxplot(vac$Age, horizontal = TRUE, xlab = "Age")

## Dotplot
yes <- 100 * colMeans(vac[, 13:32] == "yes")
dotchart(sort(yes), xlab = "Percent 'yes'", xlim = c(0, 100))

######################################################################
## 4.4 Pre-processing
######################################################################

## 4.4.1 Pre-processing categorical data
sort(table(vac$Income))
table(vac$Income2)
vacmot <- (vac[, 13:32] == "yes") + 0

## 4.4.2 Standardisation of numeric variables
vacmot.scaled <- scale(vacmot)

######################################################################
## 4.5 Principal components analysis
######################################################################

vacmot.pca <- prcomp(vacmot)
vacmot.pca

summary(vacmot.pca)

library("flexclust")
plot(predict(vacmot.pca)[, 2:3], pch = 16, col = "grey80")
projAxes(vacmot.pca, which = 2:3)


