######################################################################
## 5.2
## Distance-based methods
######################################################################

suppressWarnings(RNGversion("3.5"))

######################################################################
## 5.2.1 Distance measures
######################################################################

data("annabill", package = "MSA")
annabill

D1 <- dist(annabill)
round(D1, 2)

D2 <- dist(annabill, method = "manhattan")
D2

as.matrix(D2)

library("cluster")
daisy(annabill)

######################################################################
## 5.2.2 Hierarchical methods
######################################################################

data("risk", package = "MSA")
dim(risk)

colMeans(risk)

risk.dist <- dist(risk, method = "manhattan")                            
risk.hcl <- hclust(risk.dist, method = "complete")                        
risk.hcl
plot(risk.hcl, main = "", labels = FALSE)

c2 <- cutree(risk.hcl, h = 20)
table(c2)
c6 <- cutree(risk.hcl, k = 6)
table(c6)

c6.means <- aggregate(risk, list(Cluster = c6), mean)
round(c6.means[, -1], 1)

library("flexclust")
barchart(risk.hcl, risk, k = 6)

######################################################################
## 5.2.3 Partitioning methods
######################################################################

library("flexclust")
set.seed(1234)
PF3 <- priceFeature(500, which = "3clust")
plot(PF3)

PF3.km3 <- cclust(PF3, k = 3)
PF3.km3

parameters(PF3.km3)
clusters(PF3.km3)[1:20]

library("MSA")
clusterhulls(PF3, clusters(PF3.km3))

PF3.km28 <- stepcclust(PF3, k = 2:8, nrep = 10)
PF3.km28

plot(PF3.km28)

## 5.2.3.2 Example: Tourist Risk Taking
set.seed(1234)
risk.km28 <- stepcclust(risk, k = 2:8, nrep = 10)
plot(risk.km28)

barchart(risk.km28[["2"]])
barchart(risk.km28[["6"]])

######################################################################
## 5.2.4 Hybrid approaches
######################################################################

## 5.2.4.1 Two-step clustering

set.seed(1234)
PF3.k30 <- stepcclust(PF3, k = 30, nrep = 10)
plot(PF3.k30, data = PF3)

PF3.k30.cent <- parameters(PF3.k30)
sizes <- table(clusters(PF3.k30))
PF3.hc <- hclust(dist(PF3.k30.cent), members = sizes)
plot(PF3.hc, main = "")

PF3.ts3 <- twoStep(PF3.hc, clusters(PF3.k30), k = 3)
table(PF3.ts3)

## 5.2.4.2 Bagged clustering

data("winterActiv", package = "MSA")
colnames(winterActiv)

set.seed(1234)
winter.bc <- bclust(winterActiv, base.k = 10, base.iter = 50)
plot(winter.bc)
barchart(winter.bc, k = 5)
bwplot(winter.bc, k = 5, clusters = 5)

######################################################################
## 5.2.5 Other cluster algorithms
######################################################################

library("kohonen")
set.seed(1234)
risk.som <- som(risk, somgrid(5, 5, "rect"))
plot(risk.som, palette.name = flxPalette, main = "")


