######################################################################
## 5.3
## Model-based methods
######################################################################

suppressWarnings(RNGversion("3.5"))

######################################################################
## 5.3.1 Finite mixtures of distributions
######################################################################

## 5.3.1.1 Mixtures of normal distributions

library("flexclust")
set.seed(1234)
PF3 <- priceFeature(500, which = "3clust")

library("mclust")
PF3.m28 <- Mclust(PF3, G = 2:8)
PF3.m28

plot(PF3.m28, what = "uncertainty")
plot(PF3.m28, what = "BIC")

data("vacmot", package = "flexclust")
vacmet <- vacmotdesc[, c("Obligation", "NEP", "Vacation.Behaviour")]
vacmet <- na.omit(vacmet)
pairs(vacmet, pch = 19, col = rgb(0, 0, 0, 0.2))

vacmet.m18 <- Mclust(vacmet, G = 1:8)
vacmet.m18.equal <- Mclust(vacmet, G = 1:8, 
                           modelNames = c("EEI", "EII", "EEE"))
vacmet.m18
vacmet.m18.equal

plot(vacmet.m18, what = "classification")
plot(vacmet.m18.equal, what = "classification")

## 5.3.1.2 Mixtures of binary distributions

data("winterActiv", package = "MSA")
winterActiv2 <- winterActiv[, c("alpine skiing", "sight-seeing")]
table(as.data.frame(winterActiv2))

p <- colMeans(winterActiv2)
p
round(prod(p) * 100)

n <- nrow(winterActiv2)
expected <- function(p) {
  res <- outer(c(1 - p[1], p[1]), c(1 - p[2], p[2]))
  dimnames(res) <- setNames(rep(list(c("0", "1")), 2), 
    names(p))
  res
}
round(n * expected(p))

library("flexmix")
winterActiv2.m14 <- stepFlexmix(winterActiv2 ~ 1, k = 1:4, nrep = 10,
                                model = FLXMCmvbinary(),
                                verbose = FALSE)
winterActiv2.m14

best.winterActiv2.m14 <- getModel(winterActiv2.m14)
best.winterActiv2.m14

p <- parameters(best.winterActiv2.m14)
p
pi <- prior(best.winterActiv2.m14)
pi
round(n * (pi[1] * expected(p[, "Comp.1"]) + 
           pi[2] * expected(p[, "Comp.2"])))

set.seed(1234)
winter.m28 <- stepFlexmix(winterActiv ~ 1, k = 2:8, nrep = 10,
                          model = FLXMCmvbinary(), verbose = FALSE)
plot(winter.m28)
winter.m5 <- getModel(winter.m28, "5")
winter.m5

propBarchart(winterActiv, clusters(winter.m5), alpha = 1,
             strip.prefix = "Segment ")

######################################################################
## 5.3.2 Finite mixtures of regressions
######################################################################

data("themepark", package = "MSA")
plot(pay ~ rides, data = themepark, xlab = "number of rides",
     ylab = "willingness to pay")

set.seed(1234)
park.f1 <- stepFlexmix(pay ~ rides + I(rides^2), data = themepark,
                       k = 2, nrep = 10, verbose = FALSE)
park.f1

plot(pay ~ rides, data = themepark, col = clusters(park.f1), 
     xlab = "number of rides", ylab = "willingness to pay")
seg1 <- function(x) x
seg2 <- function(x) 0.0125*x^2
curve(seg1, from = 0, to = 50, add = TRUE)
curve(seg2, from = 0, to = 50, add = TRUE)

parameters(park.f1)
summary(refit(park.f1))

data("vacmot", package = "flexclust")
envir <- vacmotdesc[, c("Obligation", "NEP", "Vacation.Behaviour")]
envir <- na.omit(envir)
envir[, c("Obligation", "NEP")] <-
    scale(envir[, c("Obligation", "NEP")])

envir.lm <- lm(Vacation.Behaviour ~ Obligation + NEP, data = envir)
summary(envir.lm)

set.seed(1234)
envir.m15 <- stepFlexmix(Vacation.Behaviour ~ ., data = envir,
                         k = 1:5, nrep = 10, verbose = FALSE,
                         control = list(iter.max = 1000))
envir.m2 <- getModel(envir.m15)
envir.m2

summary(refit(envir.m2))

par(mfrow = c(1, 2))
plot(Vacation.Behaviour ~ Obligation, data = envir, pch = 20, 
     col = clusters(envir.m2))
abline(parameters(envir.m2)[1:2, 1], col = 1, lwd = 2)
abline(parameters(envir.m2)[1:2, 2], col = 2, lwd = 2)
plot(Vacation.Behaviour ~ NEP, data = envir, pch = 20,
     col = clusters(envir.m2))
abline(parameters(envir.m2)[c(1, 3), 1], col = 1, lwd = 2)
abline(parameters(envir.m2)[c(1, 3), 2], col = 2, lwd = 2)



