######################################################################
## 5.5
## Data structure analysis
######################################################################

suppressWarnings(RNGversion("3.5"))

######################################################################
## 5.5.2 Gorge plots
######################################################################

library("flexclust")
set.seed(1234)
PF3 <- priceFeature(500, which = "3clust")
PF2 <- priceFeature(500, which = "ellipse")
PF1 <- priceFeature(500, which = "circle")

set.seed(1234)
PF3.k3 <- relabel(stepcclust(PF3, k = 3, nrep = 10, save.data = TRUE))
PF2.k3 <- relabel(stepcclust(PF2, k = 3, nrep = 10, save.data = TRUE))
PF1.k3 <- relabel(stepcclust(PF1, k = 3, nrep = 10, save.data = TRUE))

set.seed(1234)
PF3.b29 <- bootFlexclust(PF3, k = 2:9, FUN = "cclust", nrep = 10)
PF2.b29 <- bootFlexclust(PF2, k = 2:9, FUN = "cclust", nrep = 10)
PF1.b29 <- bootFlexclust(PF1, k = 2:9, FUN = "cclust", nrep = 10)

layout(matrix(c(1, 2, 3, 0, 0, 0, 4, 5, 6), 3, 3, byrow = FALSE))

plot(PF3.k3)
plot(PF2.k3)
plot(PF1.k3)

plot(PF3.b29, xlab = "number of segments",
     ylab = "adjusted Rand index", ylim = 0:1)
plot(PF2.b29, xlab = "number of segments",
     ylab = "adjusted Rand index", ylim = 0:1)
plot(PF1.b29, xlab = "number of segments",
     ylab = "adjusted Rand index", ylim = 0:1)

print(histogram(PF3.k3, xlab = "similarity",
                main = "Natural segmentation"), newpage = FALSE,
      position = c(1/3, 2/3, 2/3, 1), more = TRUE)
print(histogram(PF2.k3, xlab = "similarity",
                main = "Reproducible segmentation"),
      position = c(1/3, 1/3, 2/3, 2/3), more = TRUE)
print(histogram(PF1.k3, xlab = "similarity",
                main = "Constructive segmentation"),
      position = c(1/3, 0, 2/3, 1/3), more = FALSE)

######################################################################
## 5.5.3 Global stability analysis
######################################################################

library("flexclust")
set.seed(1234)
PF3 <- priceFeature(500, which = "3clust")

set.seed(1234)
PF3.b29 <- bootFlexclust(PF3, k = 2:9, FUN = "cclust", nrep = 10)
oopts <- options(digits = 2)
summary(PF3.b29)
options(oopts)

boxplot(PF3.b29, ylim = c(0.2, 1), xlab = "number of segments",
        ylab = "adjusted Rand index")

## Example: Tourist risk taking

data("risk", package = "MSA")
set.seed(1234)
risk.b29 <- bootFlexclust(risk, k = 2:9, FUN = "cclust", nrep = 10)
plot(risk.b29, ylim = c(0.2, 1), xlab = "number of segments",
     ylab = "adjusted Rand index")


######################################################################
## 5.5.4 Segment level stability analysis
######################################################################

## Segment level stability within solutions

library("flexclust")
set.seed(1234)
PF3 <- priceFeature(500, which = "3clust")
PF3.k38 <- stepcclust(PF3, k = 3:8, nrep = 10)
PF3.k38 <- relabel(PF3.k38)
PF3.k3 <- PF3.k38[["3"]]
PF3.k6 <- PF3.k38[["6"]]

par(mfrow = 1:2)
plot(PF3.k3, data = PF3, main = "three segments")
plot(PF3.k6, data = PF3, main = "six segments")

PF3.r3 <- slswFlexclust(PF3, PF3.k3)
PF3.r6 <- slswFlexclust(PF3, PF3.k6)

layout(t(1:2), width = 1:2)
plot(PF3.r3, ylim = 0:1, xlab = "segment number", 
     ylab = "Jaccard coefficient", main = "three segments")
plot(PF3.r6, ylim = 0:1, xlab = "segment number", 
     ylab = "Jaccard coefficient", main = "six segments")

data("vacmot", package = "flexclust")
set.seed(1234)
vacmot.k38 <- stepcclust(vacmot, k = 3:8, method = "neuralgas",
                         nrep = 20, save.data = TRUE, verbose = FALSE)
vacmot.k38 <- relabel(vacmot.k38)
vacmot.k6 <- vacmot.k38[["6"]]
vacmot.r6 <- slswFlexclust(vacmot, vacmot.k6, method = "neuralgas",
                           FUN = "cclust")
plot(vacmot.r6, xlab = "segment number", ylab = "Jaccard coefficient", 
     ylim = 0:1)

## Segment level stability across solutions

par(mar = rep(1, 4))
slsaplot(PF3.k38)
slsaplot(vacmot.k38)



