######################################################################
## STEP 6
## Profiling segments
######################################################################

suppressWarnings(RNGversion("3.5"))

######################################################################
## 6.2 Traditional approaches to profiling market segments
######################################################################

## See Section 5.5.4
library("flexclust")
data("vacmot", package = "flexclust")
set.seed(1234)
vacmot.k38 <- stepcclust(vacmot, k = 3:8, method = "neuralgas",
                         nrep = 20, save.data = TRUE, verbose = FALSE)
vacmot.k38 <- relabel(vacmot.k38)
vacmot.k6 <- vacmot.k38[["6"]]

clMeans <- parameters(vacmot.k6)
rownames(clMeans) <- paste("Seg", 1:6, sep = ".")

print(cbind(t(clMeans), Total = colMeans(vacmot)) * 100, digits = 0)

######################################################################
## 6.3 Assisting segment profiling with visualisations
######################################################################

## 6.3.1 Identifying defining characteristics of market segments
vacmot.vdist  <- dist(t(vacmot))
vacmot.vclust <- hclust(vacmot.vdist, "ward.D2")

opar <- par(mar = c(4.1, 1, 1, 12))
plot(as.dendrogram(vacmot.vclust), horiz = TRUE, type = "triangle",
     xlab = "Height")
par(opar)

barchart(vacmot.k6, shade = TRUE, which = rev(vacmot.vclust$order))

## 6.3.2 Assessing a segmentation solution
set.seed(1234)
PF3 <- priceFeature(500, which = c("3clust"))
PF2 <- priceFeature(500, which = c("ellipse"))

c3 <- stepcclust(PF3, 3, save.data = TRUE)
c2 <- stepcclust(PF2, 3, save.data = TRUE)

opar <- par(mfrow = c(2, 2))
plot(c3)
plot(c2)
plot(c3, points = FALSE, hull.args = list(density = 10))
plot(c2, points = FALSE, hull.args = list(density = 10))
par(opar)

vacmot.pca <- prcomp(vacmot)
plot(vacmot.k6, project = vacmot.pca, which = 2:3,
     xlab = "principal component 2", ylab = "principal component 3")
projAxes(vacmot.pca, which = 2:3)

plot(vacmot.k6, project = vacmot.pca, which = 2:3,
     col = flxColors(1:6, "light"),
     points = FALSE, hull.args = list(density = 10),
     xlab = "principal component 2", ylab = "principal component 3")
projAxes(vacmot.pca, which = 2:3, col = "darkblue", cex = 1.2)


