######################################################################
## STEP 9
## Customising the marketing mix
######################################################################

## Bi-clustering solution for Australian vacation activities.
library("biclust")
data("ausActiv", package = "MSA")
ausact.bic  <- biclust(x = ausActiv, method = BCrepBimax, 
                       minc = 2, minr = 50, number = 100, maxc = 100)

## Obtain the segment memberships from the bi-clustering solution.
bcn <- biclusternumber(ausact.bic)
cl12 <- rep(NA, nrow(ausActiv))
for (k in seq_along(bcn)) {
    cl12[bcn[[k]]$Rows] <- k
}
table(cl12, exclude = NULL)
cl12.3 <- factor(!is.na(cl12) & cl12 == 3, c(FALSE, TRUE),
                 c("Not Segment 3", "Segment 3"))

######################################################################
### 9.3 Price
######################################################################

data("ausActivDesc", package = "MSA")
boxplot(spendpppd ~ cl12.3, data = ausActivDesc, 
        notch = TRUE, varwidth = TRUE, log = "y",
	ylab = "AUD per person per day")

######################################################################
### 9.4 Place
######################################################################

library("flexclust")
propBarchart(ausActivDesc, g = cl12.3,
             which = grep("^book", names(ausActivDesc)),
             layout = c(1, 1), xlab = "percent", xlim = c(-2, 102))

######################################################################
### 9.5 Promotion
######################################################################

propBarchart(ausActivDesc, g = cl12.3,
             which = grep("^info", names(ausActivDesc)),
             layout = c(1, 1), xlab = "percent", xlim = c(-2, 102))

par(las = 1)
mosaicplot(table(cl12.3, ausActivDesc$TV.channel), shade = TRUE,
           xlab = "Segment number", main = "")



