\name{twoStep}
\alias{twoStep}
\title{Infer group memberships of observations when using two-step clustering}
\description{
  Given the cluster memberships from the first step of two-step
  clustering and the hierarchical clustering result from the second step
  infer the final group memberships of observations given a specific
  number of groups.
}
\usage{
twoStep(hobject, clusters, k)
}
\arguments{
  \item{hobject}{An object of class `\code{hclust}'.}
  \item{clusters}{An integer vector containing the cluster memberships
    of observations after the first vector quantisation step.}
  \item{k}{An integer scalar with the desired number of groups.}
}
\value{
  An integer vector of length equal to \code{clusters} indicating
  the group membership implied from cutting the dendrogram.
}
\author{Friedrich Leisch}
\examples{
  data("ausActiv", package = "MSA")
  set.seed(1234)
  ausActiv.k30 <- kmeans(ausActiv, centers = 30, nstart = 10)
  ausActiv.hc <- hclust(dist(ausActiv.k30$centers),
    members = ausActiv.k30$size)
  ausActiv.ts3 <- twoStep(ausActiv.hc, ausActiv.k30$cluster, k = 3)
  plot(predict(prcomp(ausActiv))[, 1:2], col = ausActiv.ts3)
}
\keyword{cluster}

