\name{vsbd}
\alias{vsbd}
\title{Selecting variables for binary clustering}
\description{
  Implements the variable selection algorithm for binary clustering
  proposed in Brusco (2004).
}
\usage{
vsbd(x, centers, delta, phi = 1, initial.variables = 4,
     max.variables = ncol(x), nstart1 = 50, nstart2 = 100, ...)
}
\arguments{
  \item{x}{A data matrix.}
  \item{centers}{Passed to \code{\link[stats]{kmeans}}.}
  \item{delta}{A numeric value in [0, 1].}
  \item{phi}{A numeric value in (0, 1]; defaults to \code{1}.}
  \item{initial.variables}{An integer scalar; defaults to \code{4}.}
  \item{max.variables}{An integer scalar; defaults to \code{ncol(x)}.}
  \item{nstart1}{An integer scalar; defaults to \code{50}.}
  \item{nstart2}{An integer scalar; defaults to \code{100}.}
  \item{\dots}{Passed to \code{\link[stats]{kmeans}}.}
}
\value{
  Returns an integer vector of the variables which are selected.
}
\references{
  Brusco M (2004) Clustering binary data in the presence of masking
  variables. Psychological Methods 9(4):510-523.
}

\author{Bettina Grün}
\examples{
  data("winterActiv", package = "MSA")
  selected.variables <- vsbd(winterActiv[, 1:6],
    centers = 4, delta = 0.5, nstart1 = 10, nstart2 = 10)
}
\keyword{cluster}
